@@ -9,6 +9,7 @@
 #define G_LOG_DOMAIN "phosh-fader"
 
 #include "phosh-config.h"
+#include "animation.h"
 #include "fader.h"
 #include "shell.h"
 
@@ -28,6 +29,8 @@ enum {
   PROP_0,
   PROP_MONITOR,
   PROP_STYLE_CLASS,
+  PROP_FADE_OUT_TIME,
+  PROP_FADE_OUT_TYPE,
   PROP_LAST_PROP,
 };
 static GParamSpec *props[PROP_LAST_PROP];
@@ -37,10 +40,29 @@ typedef struct _PhoshFader
   PhoshLayerSurface           parent;
   PhoshMonitor               *monitor;
   char                       *style_class;
+
+  PhoshAnimation             *fadeout;
+  guint                       fade_out_time;
+  PhoshAnimationType          fade_out_type;
 } PhoshFader;
+
 G_DEFINE_TYPE (PhoshFader, phosh_fader, PHOSH_TYPE_LAYER_SURFACE)
 
 
+static void
+fadeout_value_cb (double value, PhoshFader *self)
+{
+  phosh_layer_surface_set_alpha (PHOSH_LAYER_SURFACE (self), 1.0 - value);
+}
+
+
+static void
+fadeout_done_cb (GtkWidget *self)
+{
+  gtk_widget_destroy (self);
+}
+
+
 static void
 phosh_fader_set_property (GObject      *obj,
                           guint         prop_id,
@@ -51,9 +73,14 @@ phosh_fader_set_property (GObject      *obj,
 
   switch (prop_id) {
   case PROP_MONITOR:
-    /* construct only */
     g_set_object (&self->monitor, g_value_get_object (value));
     break;
+  case PROP_FADE_OUT_TIME:
+    self->fade_out_time = g_value_get_uint (value);
+    break;
+  case PROP_FADE_OUT_TYPE:
+    self->fade_out_type = g_value_get_enum (value);
+    break;
   case PROP_STYLE_CLASS:
     g_free (self->style_class);
     self->style_class = g_value_dup_string (value);
@@ -77,6 +104,12 @@ phosh_fader_get_property (GObject    *obj,
   case PROP_MONITOR:
     g_value_set_object (value, self->monitor);
     break;
+  case PROP_FADE_OUT_TIME:
+    g_value_set_uint (value, self->fade_out_time);
+    break;
+  case PROP_FADE_OUT_TYPE:
+    g_value_set_enum (value, self->fade_out_type);
+    break;
   case PROP_STYLE_CLASS:
     g_value_set_string (value, self->style_class);
     break;
@@ -113,6 +146,7 @@ phosh_fader_dispose (GObject *object)
 {
   PhoshFader *self = PHOSH_FADER (object);
 
+  g_clear_pointer (&self->fadeout, phosh_animation_unref);
   g_clear_object (&self->monitor);
   g_clear_pointer (&self->style_class, g_free);
 
@@ -158,26 +192,39 @@ phosh_fader_class_init (PhoshFaderClass *klass)
   object_class->dispose = phosh_fader_dispose;
   widget_class->show = phosh_fader_show;
 
-  props[PROP_MONITOR] = g_param_spec_object ("monitor",
-                                             "",
-                                             "",
-                                             PHOSH_TYPE_MONITOR,
-                                             G_PARAM_CONSTRUCT_ONLY |
-                                             G_PARAM_READWRITE |
-                                             G_PARAM_STATIC_STRINGS);
-
+  props[PROP_MONITOR] =
+    g_param_spec_object ("monitor", "", "",
+                         PHOSH_TYPE_MONITOR,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  /**
+   * PhoshFader:fade-out-time:
+   *
+   * The time of a fade out animation in ms. 0 to enable any
+   * fade out.
+   */
+  props[PROP_FADE_OUT_TIME] =
+      g_param_spec_uint ("fade-out-time", "", "",
+                         0, G_MAXUINT, 0,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  /**
+   * PhoshFader:fade-out-type:
+   *
+   * The animation type for the fade out.
+   */
+  props[PROP_FADE_OUT_TYPE] =
+      g_param_spec_enum ("fade-out-type", "", "",
+                         PHOSH_TYPE_ANIMATION_TYPE,
+                         PHOSH_ANIMATION_TYPE_EASE_OUT_CUBIC,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
   /**
    * PhoshFader:style-class
    *
    * The CSS style class used for the animation
    */
-  props[PROP_STYLE_CLASS] = g_param_spec_string ("style-class",
-                                                 "",
-                                                 "",
-                                                 NULL,
-                                                 G_PARAM_CONSTRUCT_ONLY |
-                                                 G_PARAM_READWRITE |
-                                                 G_PARAM_STATIC_STRINGS);
+  props[PROP_STYLE_CLASS] =
+    g_param_spec_string ("style-class", "", "",
+                         NULL,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 }
@@ -195,3 +242,26 @@ phosh_fader_new (PhoshMonitor *monitor)
 {
   return g_object_new (PHOSH_TYPE_FADER, "monitor", monitor, NULL);
 }
+
+
+void
+phosh_fader_hide (PhoshFader *self)
+{
+  g_return_if_fail (PHOSH_IS_FADER (self));
+
+  if (self->fade_out_time == 0 || !phosh_layer_surface_has_alpha (PHOSH_LAYER_SURFACE (self))) {
+    gtk_widget_destroy (GTK_WIDGET (self));
+    return;
+  }
+
+  self->fadeout = phosh_animation_new (GTK_WIDGET (self),
+                                       0.0,
+                                       1.0,
+                                       self->fade_out_time * PHOSH_ANIMATION_SLOWDOWN,
+                                       self->fade_out_type,
+                                       (PhoshAnimationValueCallback) fadeout_value_cb,
+                                       (PhoshAnimationDoneCallback) fadeout_done_cb,
+                                       self);
+
+  phosh_animation_start (self->fadeout);
+}
