@@ -63,8 +63,9 @@ phosh_get_desktop_app_info_for_app_id (const char *app_id)
   GDesktopAppInfo *app_info = NULL;
   char *last_component;
   static char *mappings[][2] = {
-    { "org.gnome.ControlCenter", "gnome-control-center" },
-    { "gnome-usage", "org.gnome.Usage" },
+    { "Audacity", "org.audacityteam.Audacity" }, /* flatpak,X11 */
+    { "Gimp-2.10", "gimp" }, /* X11 */
+    { "krita", "org.kde.krita" }, /* X11 */
   };
 
   g_assert (app_id);
@@ -77,12 +78,8 @@ phosh_get_desktop_app_info_for_app_id (const char *app_id)
     }
   }
 
-  if (!g_str_has_suffix (app_id, ".desktop"))
-    desktop_id = g_strdup_printf ("%s.desktop", app_id);
-  else
-    desktop_id = g_strdup (app_id);
-
-  g_assert (desktop_id);
+  desktop_id = g_strdup_printf ("%s.desktop", app_id);
+  g_return_val_if_fail (desktop_id, NULL);
   app_info = g_desktop_app_info_new (desktop_id);
 
   if (app_info)
@@ -91,8 +88,10 @@ phosh_get_desktop_app_info_for_app_id (const char *app_id)
   /* try to handle the case where app-id is rev-DNS, but desktop file is not */
   last_component = strrchr(app_id, '.');
   if (last_component) {
+    /* Skip past '.' */
+    last_component++;
     g_free (desktop_id);
-    desktop_id = g_strdup_printf ("%s.desktop", last_component + 1);
+    desktop_id = g_strdup_printf ("%s.desktop", last_component);
     g_return_val_if_fail (desktop_id, NULL);
     app_info = g_desktop_app_info_new (desktop_id);
     if (app_info)
